@@ -1253,23 +1253,38 @@
                 status: { value: 200, writable: false },
                 statusText: { value: 'OK', writable: false },
             });
-            if ( this.onreadystatechange !== null ) {
-                setTimeout(( ) => {
-                    const ev = new Event('readystatechange');
-                    this.onreadystatechange.call(this, ev);
-                }, 1);
-            }
-            if ( this.onload !== null ) {
-                setTimeout(( ) => {
-                    const ev = new Event('load');
-                    this.onload.call(this, ev);
-                }, 1);
-            }
+            this.dispatchEvent(new Event('readystatechange'));
+            this.dispatchEvent(new Event('load'));
+            this.dispatchEvent(new Event('loadend'));
         }
     };
 })();
 
 
+// https://github.com/uBlockOrigin/uAssets/issues/10323#issuecomment-992312847
+// https://github.com/AdguardTeam/Scriptlets/issues/158
+/// window-close-if.js
+(function() {
+    const arg1 = '{{1}}';
+    let reStr;
+    if ( arg1 === '{{1}}' || arg1 === '' ) {
+        reStr = '^';
+    } else if ( arg1.startsWith('/') && arg1.endsWith('/') ) {
+        reStr = arg1.slice(1, -1);
+    } else {
+        reStr = arg1.replace(/[.*+?^${}()|[\]\\]/g, '\\$&');
+    }
+    try {
+        const re = new RegExp(reStr);
+        if ( re.test(`${window.location.pathname}${window.location.search}`) ) {
+            window.close();
+        }
+    } catch(ex) {
+        console.log(ex);
+    }
+})();
+
+
 // https://github.com/gorhill/uBlock/issues/1228
 /// window.name-defuser
 (function() {
@@ -1340,9 +1355,11 @@
 // https://github.com/uBlockOrigin/uAssets/issues/8
 /// alert-buster.js
 (function() {
-    window.alert = function(a) {
-        console.info(a);
-    };
+    window.alert = new Proxy(window.alert, {
+        apply: function(a) {
+            console.info(a);
+        },
+    });
 })();
 
 
