@@ -95,7 +95,7 @@
   The domFilterer makes use of platform-dependent user stylesheets[1].
 
   [1] "user stylesheets" refer to local CSS rules which have priority over,
-       and can't be overriden by a web page's own CSS rules.
+       and can't be overridden by a web page's own CSS rules.
 
 */
 
@@ -393,7 +393,7 @@ vAPI.SafeAnimationFrame = class {
     const startMutationObserver = function() {
         if ( domLayoutObserver !== undefined ) { return; }
         domLayoutObserver = new MutationObserver(observerHandler);
-        domLayoutObserver.observe(document.documentElement, {
+        domLayoutObserver.observe(document, {
             //attributeFilter: [ 'class', 'id' ],
             //attributes: true,
             childList: true,
@@ -469,13 +469,11 @@ vAPI.injectScriptlet = function(doc, text) {
     try {
         script = doc.createElement('script');
         script.appendChild(doc.createTextNode(text));
-        (doc.head || doc.documentElement).appendChild(script);
+        (doc.head || doc.documentElement || doc).appendChild(script);
     } catch (ex) {
     }
     if ( script ) {
-        if ( script.parentNode ) {
-            script.parentNode.removeChild(script);
-        }
+        script.remove();
         script.textContent = '';
     }
 };
@@ -1026,7 +1024,6 @@ vAPI.DOMFilterer = class {
     // Extract all classes/ids: these will be passed to the cosmetic
     // filtering engine, and in return we will obtain only the relevant
     // CSS selectors.
-    const reWhitespace = /\s/;
 
     // https://github.com/gorhill/uBlock/issues/672
     // http://www.w3.org/TR/2014/REC-html5-20141028/infrastructure.html#space-separated-tokens
@@ -1041,19 +1038,21 @@ vAPI.DOMFilterer = class {
         queriedIds.add(s);
     };
 
+    // https://github.com/uBlockOrigin/uBlock-issues/discussions/2076
+    //   Performance: avoid using Element.classList
     const classesFromNode = (node, out) => {
-        const s = node.className;
-        if ( typeof s !== 'string' || s.length === 0 ) { return; }
-        if ( reWhitespace.test(s) === false ) {
-            if ( queriedClasses.has(s) ) { return; }
-            out.push(s);
-            queriedClasses.add(s);
-            return;
-        }
-        for ( const s of node.classList.values() ) {
-            if ( queriedClasses.has(s) ) { continue; }
-            out.push(s);
-            queriedClasses.add(s);
+        const s = node.getAttribute('class');
+        if ( typeof s !== 'string' ) { return; }
+        const len = s.length;
+        for ( let beg = 0, end = 0, token = ''; beg < len; beg += 1 ) {
+            end = s.indexOf(' ', beg);
+            if ( end === beg ) { continue; }
+            if ( end === -1 ) { end = len; }
+            token = s.slice(beg, end);
+            beg = end;
+            if ( queriedClasses.has(token) ) { continue; }
+            out.push(token);
+            queriedClasses.add(token);
         }
     };
 
@@ -1171,10 +1170,14 @@ vAPI.DOMFilterer = class {
             //   Look-up safe-only selectors to mitigate probability of
             //   html/body elements of erroneously being targeted.
             const ids = [], classes = [];
-            idFromNode(document.documentElement, ids);
-            idFromNode(document.body, ids);
-            classesFromNode(document.documentElement, classes);
-            classesFromNode(document.body, classes);
+            if ( document.documentElement !== null ) {
+                idFromNode(document.documentElement, ids);
+                classesFromNode(document.documentElement, classes);
+            }
+            if ( document.body !== null ) {
+                idFromNode(document.body, ids);
+                classesFromNode(document.body, classes);
+            }
             if ( ids.length !== 0 || classes.length !== 0 ) {
                 messaging.send('contentscript', {
                     what: 'retrieveGenericCosmeticSelectors',
